pub struct Projective<P>where
P: DOCurveConfig,{
pub e: <P as CurveConfig>::BaseField,
pub z: <P as CurveConfig>::BaseField,
pub u: <P as CurveConfig>::BaseField,
pub t: <P as CurveConfig>::BaseField,
}Expand description
Fractional coordinates as utilised in https://doubleodd.group/doubleodd-jq.pdf, but first defined in https://www.sciencedirect.com/science/article/pii/S0020019007001433. Affine point (e,u) is represented as (E:Z:U:T) such that:
- Z != 0
- e = E/Z
- u = U/Z
- u**2 / T/Z
Fields
e: <P as CurveConfig>::BaseFieldE / Z projection of the affine e
z: <P as CurveConfig>::BaseFieldProjective multiplicative inverse.
u: <P as CurveConfig>::BaseFieldU / Z projection of the affine u
t: <P as CurveConfig>::BaseFieldAdditional formula for faster addition: T = U^2/Z
Implementations
Sourceimpl<P> Projective<P>where
P: DOCurveConfig,
impl<P> Projective<P>where
P: DOCurveConfig,
Sourcepub const fn new_unchecked(
e: <P as CurveConfig>::BaseField,
z: <P as CurveConfig>::BaseField,
u: <P as CurveConfig>::BaseField,
t: <P as CurveConfig>::BaseField,
) -> Projective<P>
pub const fn new_unchecked( e: <P as CurveConfig>::BaseField, z: <P as CurveConfig>::BaseField, u: <P as CurveConfig>::BaseField, t: <P as CurveConfig>::BaseField, ) -> Projective<P>
Constructs a new group element without checking whether the coordinates specify a point in the subgroup.
Sourcepub fn new(
e: <P as CurveConfig>::BaseField,
z: <P as CurveConfig>::BaseField,
u: <P as CurveConfig>::BaseField,
t: <P as CurveConfig>::BaseField,
) -> Projective<P>
pub fn new( e: <P as CurveConfig>::BaseField, z: <P as CurveConfig>::BaseField, u: <P as CurveConfig>::BaseField, t: <P as CurveConfig>::BaseField, ) -> Projective<P>
Constructs a new group element in a way while enforcing that points are in the prime-order subgroup.